##  Overview of the SAP LeanIX Meta Model
SAP LeanIX has a predefined meta model that provides a fast time-to-value to start and maintain organizations' enterprise architecture work with SAP LeanIX. It includes best practices and knowledge from our work with more than 1,000 customers and gives clear guidance on documenting all elements of your organization's enterprise architecture.
The SAP LeanIX meta model is prescriptive: Our core belief is that using this meta model as a standard will provide maximum efficiency and long-term success for companies' enterprise architecture practices. Adopting this meta model will ensure the smooth realization of all SAP LeanIX-recommended and -supported reporting and use case scenarios.
Although the meta model is fully configurable (explained in detail below), any modifications to the meta model will affect all your SAP LeanIX modeling practices, reporting, etc. This may result in limitations for future use cases that might not be resolved efficiently or in a standardized way.
Overview of the SAP LeanIX meta model with examples
![Overview of Meta Model](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275732167a441014b56ed6ccf18304d6_LowRes.png)
**Note**
SAP LeanIX updated its [Meta Model v3](https://help.sap.com/docs/leanix/ea/meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD) and introduced the enhanced meta model v4 for new customers. Existing customers currently using the meta model v3 are not required to migrate, but they have the option to proactively choose the meta model v4. For a detailed understanding of the changes and the differences between the meta model v3 and meta model v4, see [Delta to Meta Model v3](https://help.sap.com/docs/leanix/ea/delta-to-meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD).
You can determine whether your workspace is leveraging the meta model v3 or meta model v4 by examining the names of specific fact sheet types. If your workspace includes fact sheet types like user group, project, and process, it indicates that it is based on the meta model v3.
